package
Version:
v0.0.0-...-dafe3aa
Opens a new window with list of versions in this module.
Published: Oct 27, 2025
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FileInfo struct {
Length int64
Path []string
Md5sum string `bencode:"md5sum,omitempty"`
}
type InfoDict struct {
PieceLength int64
Pieces string
Private int
Name string
Length int64 `bencode:"length,omitempty"`
Files []FileInfo `bencode:"files,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.